

# **************************************************
# * Author - Shane Baldacchino                     *
# * Version - 1.0                                  *
# * Email - shane@baldacchino.net                  *
# * File Name - ExetelData.ps1                     *
# * Script Language - Microsoft PowerShell         *   
# * Creation Date - 21st April 2016                *
# **************************************************


#----------------  EDIT BELOW THIS LINE  --------------------------------------------------------------
#ISP URL to grab data from
$ISPurl = 'https://www.exetel.com.au/members/usagemeter_xml.php?baldacchino,aha2940UW'
#Pattern match Peak & OffPeak Upload & Download
$PeakDownload =  '(?i)<PeakDownload[^>]*>(.*)</PeakDownload>'
$PeakUpload =  '(?i)<PeakUpload[^>]*>(.*)</PeakUpload>'
$OffpeakDownload =  '(?i)<OffpeakDownload[^>]*>(.*)</OffpeakDownload>'
$OffpeakUpload =  '(?i)<OffpeakUpload[^>]*>(.*)</OffpeakUpload>'
#HomeVision Pro URL to Webserver
$HVProUrl = "http://10.0.0.202:11080"
#Homevision Pro post paramters 
$parameters = "var+93+%3D="
#---------------- DO NOT EDIT BELOW THIS LINE  ---------------------------------------------------------


#Download Exetel usage data
Write-Host $(Get-Date) "| Downloading data from Exetel XML feed"
$webclient = New-Object System.Net.WebClient
$html = $webclient.DownloadString($ISPurl)

#Parse data and look for useful information
$resultPeakDownload = [Regex]::Matches($html, $PeakDownload)
$resultPeakUpload = [Regex]::Matches($html, $PeakUpload)
$resultOffpeakDownload = [Regex]::Matches($html, $OffpeakDownload)
$resultOffpeakUpload = [Regex]::Matches($html, $OffpeakUpload)

#Manipulate and get total
$TrafficTotal = [math]::Round(([int]$resultOffpeakDownload.Groups[1].Value + [int]$resultPeakDownload.Groups[1].Value + [int]$resultOffpeakUpload.Groups[1].Value + [int]$resultPeakUpload.Groups[1].Value) / 1024)  
Write-Host $(Get-Date) "| Traffic Total = " $TrafficTotal"gb"

#Divide by 10 as Homevision pro is 8-bit
$HVProTraffic = [math]::Round($TrafficTotal/10)
Write-Host $(Get-Date) "| Divide by 10 for Homevision Pro and round to nearest integer  = " $HVProTraffic
$parameters = "var+93+%3D=" + $HVProTraffic

#Post to Homevision Pro
Write-Host $(Get-Date) "| Post to Homevision Pro"
$http_request = New-Object -ComObject Msxml2.XMLHTTP
$http_request.open('POST', $HVPROurl, $false)
$http_request.setRequestHeader("Content-type",
"application/x-www-form-urlencoded")
$http_request.setRequestHeader("Content-length", $parameters.length)
$http_request.setRequestHeader("Connection", "close")
$http_request.send($parameters)
$http_request.statusText	

Write-Host $(Get-Date) "| Script complete"